@@ -2,7 +2,7 @@
 __all__ = ('DockerDaemon',)
 
 from types import TracebackType
-from typing import Dict, Optional, Type
+from typing import Any, Mapping, Optional, Type
 
 from loguru import logger
 import attr
@@ -53,9 +53,15 @@ class DockerDaemon:
 
     def provision(self,
                   image: str,
+                  command: Optional[str] = None,
                   *,
-                  volumes: Optional[Dict[str, str]] = None,
-                  network_mode: str = 'bridge'
+                  entrypoint: Optional[str] = None,
+                  environment: Optional[Mapping[str, str]] = None,
+                  network_mode: str = 'bridge',
+                  name: Optional[str] = None,
+                  ports: Optional[Mapping[int, int]] = None,
+                  user: Optional[str] = None,
+                  volumes: Optional[Mapping[str, Any]] = None,
                   ) -> Container:
         """Creates a Docker container from a given image.
 
@@ -63,13 +69,33 @@ class DockerDaemon:
         ---------
         image: str
             The name of the Docker image that should be used.
-        volumes: Dict[str, str], optional
+        command: str
+            The command that should be run inside the container. If no
+            command is given, the default command for the Docker image will
+            be used instead.
+        name: str, optional
+            The name that should be given to the Docker container. If no name
+            is given, Docker will automatically generate one instead.
+        user: str, optional
+            The user that should be used by the container. If none is given,
+            the default user for that container image will be used.
+        entrypoint: str, optional
+            The entrypoint that should be used by the container. If none is
+            given, the default entrypoint for the image will be used.
+        environment: Mapping[str, str], optional
+            An optional set of additional environment variables, indexed by
+            name, that should be used by the system.
+        volumes: Mapping[str, str], optional
             An optional set of volumes that should be mounted inside the
             container, specified as a dictionary where keys represent a host
             path or volume name, and values are a dictionary containing
             the following keys: :code:`bind`, the path to mount the volume
             inside the container, and :code:`mode`, specifies whether the
             mount should be read-write :code:`rw` or read-only :code:`ro`.
+        ports: Mapping[int, int], optional
+            An optional dictionary specifying port mappings between the host
+            and container, where keys represent container ports and values
+            represent host ports.
         network_mode: str
             Specifies the networking mode that should be used by the
             container. Can be either :code:`bridge`, :code`none`,
@@ -83,8 +109,14 @@ class DockerDaemon:
         logger.debug(f"provisioning container for image [{image}]")
         docker_container = \
             self.client.containers.run(image,
+                                       command=command,
                                        stdin_open=True,
                                        detach=True,
+                                       name=name,
+                                       entrypoint=entrypoint,
+                                       environment=environment,
+                                       ports=ports,
+                                       user=user,
                                        volumes=volumes,
                                        network_mode=network_mode)
         container = self.attach(docker_container.id)
